# ✨ panel-sharing

We want to

- to make it really easy for the Panel community to develop and share live apps

We provide

- an interactive platform for developing and sharing Panel apps

![Project Intro](assets/videos/project-intro.gif)

This project draws inspiration from other app dev and sharing tools like

- [stlite](https://github.com/whitphx/stlite), [shinylive](https://shinylive.io/py/examples/)
- [CodeSandbox](https://codesandbox.io/), [JS Fiddle](https://jsfiddle.net/) etc.

⚠️ THIS PROJECT IS IN AN ALPHA STATE AND WILL CHANGE. USE IT AT YOUR OWN RISK.

## 🚀 Get started in under a minute

Install `panel-sharing` including the *`examples` dependencies*.

```bash
pip install  panel-sharing[examples]
```

Explore the sample app

```bash
pn hello panel-sharing
```

You can now find app in the `examples/awesome-panel/panel-sharing` folder.

## ⭐ Support

Please support [Panel](https://panel.holoviz.org) and
[awesome-panel](https://awesome-panel.org) by giving the projects a star on Github:

- [holoviz/panel](https://github.com/holoviz/panel).
- [awesome-panel/awesome-panel](https://github.com/awesome-panel/awesome-panel).

Thanks

## ❤️ Contribute

If you are looking to contribute to this project you can find ideas in the [issue tracker](https://github.com/awesome-panel/panel-sharing/issues). To get started check out the [DEVELOPER_GUIDE](DEVELOPER_GUIDE.md).

I would love to support and receive your contributions. Thanks.

[![Hacktober Fest](https://github.blog/wp-content/uploads/2022/10/hacktoberfestbanner.jpeg?fit=1200%2C630)](https://github.com/awesome-panel/panel-sharing/issues).

## Monitor

[![PyPI version](https://badge.fury.io/py/panel-sharing.svg)](https://pypi.org/project/panel-sharing/)
[![Downloads](https://pepy.tech/badge/panel-sharing/month)](https://pepy.tech/project/panel-sharing)
![Python Versions](https://img.shields.io/badge/python-3.7%20%7C%203.8%20%7C%203.9%20%7C%203.10-blue)
[![License](https://img.shields.io/badge/License-MIT%202.0-blue.svg)](https://opensource.org/licenses/MIT)
![Test Results](https://github.com/awesome-panel/panel-sharing/actions/workflows/tests.yaml/badge.svg?branch=main)
